pub enum SpecificLocation {
Aligned(NonZero<u32>),
At(Frame),
Below {
location: Frame,
with_alignment: NonZero<u32>,
},
}🔬This is a nightly-only experimental API. (
kernel_physical_allocator_location)Variants
Aligned(NonZero<u32>)
🔬This is a nightly-only experimental API. (
kernel_physical_allocator_location)The mapping must be aligned to a specific number of Frames
At(Frame)
🔬This is a nightly-only experimental API. (
kernel_physical_allocator_location)The mapping will fail if it cannot be allocated at this exact location
Below
🔬This is a nightly-only experimental API. (
kernel_physical_allocator_location)The mapping must be below this location, aligned to with_alignment number of Frames